@@ -95,7 +95,7 @@ colorPalette <- function(name, n = NULL) {
       "dark3" = c("#222831", "#393E46", "#00ADB5", "#EEEEEE"),
       "flora" = c("#000000", "#f2f2eb", "#ccb77c", "#523402"),
       "gogh" = c("#8699b5", "#161918", "#9d8018", "#232d8a", "#b4ad5a", "#c2ccd5"),
-      "house" = c("#191919", "white", "#960606", "#cca222", "#036440"),
+      "house" = c("#191919", "white", "#ab3920", "#cca222", "#036440"),
       "jasp" = c("#14a1e3", "#ffffff", "#f7971c", "#8cc63e", "#000000"),
       "jfa" = c("#2a94d1", "#e89643", "#233e4a"),
       "jungle" = c("#4e6349", "#614128", "#171812", "#698144", "#917861"),
